@@ -5,7 +5,7 @@
 @Author: xiaoshuyui
 @Date: 2020-07-10 10:33:39
 @LastEditors: xiaoshuyui
-@LastEditTime: 2020-07-10 10:34:13
+@LastEditTime: 2020-07-13 14:21:34
 '''
 
 from . import getMultiShapes
@@ -28,4 +28,14 @@ def getJsons(imgPath,maskPath,savePath,yamlPath = ''):
         i_mask = i.replace(imgPath,maskPath)
         print(i)
 
-        getMultiShapes.getMultiShapes(i,i_mask,savePath,yamlPath)
\ No newline at end of file
+        getMultiShapes.getMultiShapes(i,i_mask,savePath,yamlPath)
+
+def getXmls(imgPath,maskPath,savePath):
+    oriImgs = glob.glob(imgPath+os.sep+'*.jpg')
+    maskImgs = glob.glob(maskPath+os.sep+'*.jpg')
+    
+    for i in oriImgs:
+        i_mask = i.replace(imgPath,maskPath)
+        print(i)
+
+        getMultiShapes.getMultiObjs_voc(i,i_mask,savePath)
\ No newline at end of file
